<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://www.tropicalseo.net
 * @since      1.0.0
 *
 * @package    DashyLite
 * @subpackage DashyLite/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    DashyLite
 * @subpackage DashyLite/admin
 * @author     Tropicalista <tropicalseotool@gmail.com>>
 */
class DashyLite_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in DashyLite_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The DashyLite_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/dashylite-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in DashyLite_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The DashyLite_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/dashylite-admin.js', array( 'jquery','jquery-ui-draggable','jquery-ui-resizable' ), $this->version, true );

	}

	/**
	 * Register the administration menu for this plugin into the WordPress Dashboard menu.
	 *
	 * @since    1.0.0
	 */
	public function add_plugin_admin_menu() {

	    /*
	     * Add a settings page for this plugin to the Settings menu.
	     *
	     * NOTE:  Alternative menu locations are available via WordPress administration menu functions.
	     *
	     *        Administration Menus: http://codex.wordpress.org/Administration_Menus
	     *
	     */

		add_menu_page( 'Dashy Lite', 'Dashy Lite', 'manage_options', $this->plugin_name, array($this, 'display_plugin_main_page'), 'dashicons-chart-bar', 6  );
		add_submenu_page( $this->plugin_name, 'Settings', 'Edit settings', 'manage_options', $this->plugin_name . 'settings', array($this, 'display_plugin_setup_page') );

	}

	/**
	* Add settings action link to the plugins page.
	*
	* @since  1.0.0
	*/
	public function add_action_links( $links ) {
	    /*
	    *  Documentation : https://codex.wordpress.org/Plugin_API/Filter_Reference/plugin_action_links_(plugin_file_name)
	    */
	   $settings_link = array(
	    '<a href="' . admin_url( 'admin.php?page=' . $this->plugin_name ) . 'settings">' . __('Settings', $this->plugin_name) . '</a>',
	   );
	   return array_merge(  $settings_link, $links );

	}

	/**
	 * Render the main page for plugin
	 *
	 * @since  1.0.0
	 */
	public function display_plugin_main_page() {
		include_once 'partials/dashylite-display.php';
	}

	/**
	 * Render the options page for plugin
	 *
	 * @since  1.0.0
	 */
	public function display_plugin_setup_page() {
		include_once 'partials/dashylite-admin-display.php';
	}

	/**
	*
	* admin/class-wp-cbf-admin.php
	*
	**/
	public function options_update() {

		register_setting($this->plugin_name, $this->plugin_name, array($this, 'validate'));

	}

	/**
	*
	* Store the settings
	*
	**/
	public function validate($input) 
	{
	    // All checkboxes inputs        
	    $valid = array();

	    //Cleanup
	    $valid['view'] = sanitize_text_field($input['view']);
	    
	    return $valid;
	}

	/**
	*	Insert widget
	*/
	public function list_widgets()
	{
	    global $wpdb;
	    $table = $wpdb->prefix . 'dashylite';

		$widgets = $wpdb->get_results( "SELECT * FROM $table" );

		foreach ($widgets as $row) { // Use reference so we can modify in place
			$row->settings = json_decode($row->settings);
		}
	    header('Content-type: application/json');
	    header('Cache-Control: no-cache, must-revalidate');
	    header('Expires: ' . date('r'));

		echo json_encode($widgets);

		// Always exit when doing Ajax
		exit();

	}

	/**
	*	Insert widget
	*/
	public function add_widget()
	{
	    global $wpdb;
	    $table = $wpdb->prefix . 'dashylite';

		$widget = $_POST['widget'];

		$widget = array( 
					'name' => $widget['name'], 
					'label' => $widget['label'], 
					'x' => isset($widget['x']) ?: 0, 
					'y' => isset($widget['y']) ?: 0, 
					'kind' => isset($widget['kind']) ?: 'analytics', 
					'width' => isset($widget['width']) ?: 2, 
					'height' => isset($widget['height']) ?: 2, 
					'minWidth' => isset($widget['minWidth']) ?: 2, 
					'minHeight' => isset($widget['minHeight']) ?: 2, 
					'maxWidth' => isset($widget['maxWidth']) ?: 10, 
					'maxHeight' => isset($widget['maxHeight']) ?: 10, 
					'settings' => json_encode($widget['settings'])
				);

		$wpdb->insert( 
			$table, 
			$widget
		);

		$widget['id'] = $wpdb->insert_id;
		$widget['settings'] = json_decode($widget['settings']);

	    header('Content-type: application/json');
	    header('Cache-Control: no-cache, must-revalidate');
	    header('Expires: ' . date('r'));
		
		echo json_encode($widget);
		exit();
	}

	/**
	*	Insert widget
	*/
	public function update_widget()
	{
	    global $wpdb;
	    $table = $wpdb->prefix . 'dashylite';

		$widget = $_POST['widget'];

		$settings = json_encode($widget['settings']);

		$data = array( 
					'name' => $widget['name'], 
					'label' => $widget['label'], 
					'x' => $widget['x'], 
					'y' => $widget['y'], 
					'kind' => $widget['kind'], 
					'width' => $widget['width'], 
					'height' => $widget['height'], 
					'minWidth' => $widget['minWidth'], 
					'minHeight' => $widget['minHeight'], 
					'maxWidth' => $widget['maxWidth'], 
					'maxHeight' => $widget['maxHeight'], 
					'settings' => $settings
				);

		$wpdb->update( 
			$table, 
			$data, 
			array( 'ID' => $widget['id'] )
		);

	    header('Content-type: application/json');
	    header('Cache-Control: no-cache, must-revalidate');
	    header('Expires: ' . date('r'));
		
		echo json_encode($widget);
		exit();
	}

	function update_multi(){

	    global $wpdb;

		$table_name = $wpdb->prefix . 'dashylite';
		$widgets = $_POST['widgets'];

		$ids = array();
		
		$sql = "INSERT INTO $table_name (id,x,y,width,height) VALUES ";
		foreach ($widgets as $id => $widget) {
			$sql .= sprintf("(%d, %d, %d, %d, %d),", $widget['id'], $widget['x'], $widget['y'], $widget['width'], $widget['height']);
		}
		$sql = rtrim($sql, ",");
		$idsList = substr(implode(",", $ids), 0);

		$sql .= " ON DUPLICATE KEY UPDATE x=VALUES(x),y=VALUES(y),width=VALUES(width),height=VALUES(height);";

		$wpdb->query($sql);
	    header('Content-type: application/json');
	    header('Cache-Control: no-cache, must-revalidate');
	    header('Expires: ' . date('r'));
		
		exit();

	}

	function delete_widget(){

	    global $wpdb;

		$table_name = $wpdb->prefix . 'dashylite';
		$widget = $_POST['widget'];

		$widget = $wpdb->query( "DELETE FROM $table_name WHERE id = $widget" );

		$wpdb->query($sql);
	    header('Content-type: application/json');
	    header('Cache-Control: no-cache, must-revalidate');
	    header('Expires: ' . date('r'));
		
		exit();

	}

}
