<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @link       http://www.tropicalseo.net
 * @since      1.0.0
 *
 * @package    DashyLite 
 * @subpackage DashyLite/admin/partials
 */

//Grab all options
$options = get_option($this->plugin_name);

// Cleanup
$view = $options['view'];

$client = new Google_Client();
$client->setAuthConfig( dirname( __FILE__ ) . '/google.json');

$client->addScope(Google_Service_Analytics::ANALYTICS_READONLY);

$client->setAccessToken($options['token']);

if($client->isAccessTokenExpired()){
    $token = $options['token']['refresh_token'];
    $client->refreshToken($token);
}

$token = $client->getAccessToken();
$accessToken = $token['access_token'];

?>

<!-- This file should primarily consist of HTML with a little bit of PHP. -->
<div class="wrap"  id="manage-vue">

  <button id="show-modal" class="button button-primary" @click="openModal()">Add widget</button>

  <modal v-if="showModal" :item="item" :edit="edit"> 
    <h3 slot="header" class="modal-title">
      Edit {{item.name}}
    </h3>

    <div slot="footer">
      <button type="button" class="button button-primary" @click="showModal = false">Close</button>
      <button type="button" class="button button-primary" @click="saveWidget(item)">
       Submit
      </button>
    </div>
  </modal>

    <div class="grid-stack">

        <dashboard-widget v-for="widget in widgets" v-bind:widget="widget" :key="widget.id" ref="widgets"></dashboard-widget>

    </div>

</div>


<script type="text/javascript" src="https://cdn.jsdelivr.net/lodash/4.17.4/lodash.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/axios/0.17.1/axios.min.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/qs/6.5.1/qs.min.js"></script>
<script type="text/javascript" src="//cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/js/toastr.min.js"></script>
<link href="//cdnjs.cloudflare.com/ajax/libs/toastr.js/latest/css/toastr.min.css" rel="stylesheet">

<script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/vue/2.3.0/vue.js"></script>

<link rel="stylesheet" href="//cdnjs.cloudflare.com/ajax/libs/gridstack.js/0.2.6/gridstack.min.css" />
<script src="https://cdnjs.cloudflare.com/ajax/libs/gridstack.js/0.3.0/gridstack.all.js"></script>


<script>
(function(w,d,s,g,js,fs){
  g=w.gapi||(w.gapi={});g.analytics={q:[],ready:function(f){this.q.push(f);}};
  js=d.createElement(s);fs=d.getElementsByTagName(s)[0];
  js.src='https://apis.google.com/js/platform.js';
  fs.parentNode.insertBefore(js,fs);js.onload=function(){g.load('analytics');};
}(window,document,'script'));

// global variables
var view = '<?php echo $view ?>';
var access_token = '<?php echo($accessToken) ?>';

</script>

<!-- template for the modal component -->
<script type="text/x-template" id="modal-template">
  <transition name="modal">
    <div class="modal-mask">
      <div class="modal-wrapper">
        <div class="modal-container">

          <div class="modal-header">
            <slot name="header">
              default header
            </slot>
          </div>

          <div class="modal-body">
            <slot name="body">
              <form action="#">
                  <div class="input-group">
                      <label for="name">Title</label>
                      <input v-model="item.name" type="text" name="name" class="form-control" autofocus>
                  </div>
                      <label for="metrics">Metrics</label>
                      <select v-model="item.settings" name="metrics">
                        <optgroup v-for="(option, key) in metricOptions" v-bind:label="key">
                          <option v-for="sub in option" v-bind:value="sub.value">{{sub.label}}</option>
                        </optgroup>                    
                      </select>                  
                      <label for="date">Date</label>
                      <select v-model="item.settings.date" name="date">
                        <option v-for="option in dateOptions" v-bind:value="option.value">
                          {{ option.label }}
                        </option>
                      </select>                  
              </form>
            </slot>
          </div>

          <div class="modal-footer">
            <slot name="footer">
            </slot>
          </div>
        </div>
      </div>
    </div>
  </transition>
</script>

<script type="text/x-template" id="my-widget">

<div class="grid-stack-item" :data-gs-x="widget.x" :data-gs-y="widget.y" :data-gs-width="widget.width" :data-gs-height="widget.height" :data-gs-min-width="widget.minWidth" :data-gs-min-height="widget.minHeight" :data-gs-max-width="widget.maxWidth" :data-gs-max-height="widget.maxHeight" :data-gs-id="widget.id">
  <div class="grid-stack-item-content">
    <div class="widget-content">
      <div class="box-header">
        {{widget.name}}
        <span class="toolbar">
          <a class="btn btn-box-tool" v-on:click="$parent.editWidget(widget.id)"><i class="dashicons dashicons-admin-generic"></i></a>
          <a v-on:click="$parent.deleteWidget(widget.id)" class="btn btn-box-tool">
            <i class="dashicons dashicons-no"></i>
          </a>
        </span>
      </div>
      <div v-bind:id="'widget-' + widget.id" class="box-body"></div>
    </div>
  </div>
</div>

</script>